@@ -22,7 +22,6 @@ This private submodule is *not* intended for importation by downstream callers.
 
 # ....................{ IMPORTS                           }....................
 from beartype.roar import BeartypeDecorParamNameException
-from beartype._decor._cache.cachehint import coerce_hint_pep
 from beartype._decor._code.codesnip import (
     ARG_NAME_GETRANDBITS,
     CODE_INIT_ARGS_LEN,
@@ -36,10 +35,13 @@ from beartype._decor._code._pep.pepcode import (
     pep_code_check_return,
 )
 from beartype._decor._data import BeartypeData
+from beartype._util.hint.pep.proposal.pep484585.utilpep484585func import (
+    reduce_hint_pep484585_func_return)
+from beartype._util.hint.utilhintconv import sanify_hint_root
 from beartype._util.hint.utilhinttest import is_hint_ignorable
 from beartype._util.text.utiltextlabel import (
-    label_callable_decorated_param,
-    label_callable_decorated_return,
+    prefix_callable_decorated_param,
+    prefix_callable_decorated_return,
 )
 from beartype._util.text.utiltextmagic import CODE_INDENT_1
 from inspect import Parameter, Signature
@@ -78,7 +80,7 @@ _RETURN_HINT_EMPTY = Signature.empty
 (i.e., return *not* annotated with a type hint).
 '''
 
-# ....................{ CODERS                            }....................
+# ....................{ GENERATORS                        }....................
 def generate_code(data: BeartypeData) -> str:
     '''
     Generate a Python code snippet dynamically defining the wrapper function
@@ -132,7 +134,8 @@ def generate_code(data: BeartypeData) -> str:
               overwritten by a function accepting a parameter of the same name,
               this unlikely edge case is guarded against elsewhere.
 
-          * Statements type checking parameters passed to the decorated callable.
+          * Statements type checking parameters passed to the decorated
+            callable.
           * A call to the decorated callable.
           * A statement type checking the value returned by the decorated
             callable.
@@ -142,7 +145,7 @@ def generate_code(data: BeartypeData) -> str:
     BeartypeDecorParamNameException
         If the name of any parameter declared on this callable is prefixed by
         the reserved substring ``__bear``.
-    BeartypeDecorHintNonPepException
+    BeartypeDecorHintNonpepException
         If any type hint annotating any parameter of this callable is neither:
 
         * **PEP-compliant** (i.e., :mod:`beartype`-agnostic hint compliant with
@@ -157,17 +160,35 @@ def generate_code(data: BeartypeData) -> str:
     '''
     assert data.__class__ is BeartypeData, f'{repr(data)} not @beartype data.'
 
-    # Python code snippet type-checking all annotated parameters of this
-    # callable and local scope required to do so.
-    code_params = _code_check_params(data)
+    # Python code snippet type-checking all callable parameters if one or more
+    # such parameters are annotated with unignorable type hints *OR* the empty
+    # string otherwise.
+    code_check_params = _code_check_params(data)
 
-    # Python code snippet type-checking the annotated return of this callable
-    # and local scope required to do so.
-    code_return = _code_check_return(data)
+    # Python code snippet type-checking the callable return if this return is
+    # annotated with an unignorable type hint *OR* the empty string otherwise.
+    code_check_return = _code_check_return(data)
+
+    # If the callable return requires *NO* type-checking...
+    if not code_check_return:
+        # If all callable parameters also require *NO* type-checking, this
+        # callable itself requires *NO* type-checking. In this case, return the
+        # empty string instructing the parent @beartype decorator to reduce to
+        # a noop (i.e., the identity decorator returning this callable as is).
+        if not code_check_params:
+            return ''
+        # Else, one or more callable parameters require type-checking.
+
+        # Python code snippet calling this callable unchecked, returning the
+        # value returned by this callable from this wrapper.
+        code_check_return = CODE_RETURN_UNCHECKED.format(
+            func_call_prefix=data.func_wrapper_code_call_prefix)
+    # Else, the callable return requires type-checking.
 
     # Python code snippet declaring all optional private beartype-specific
-    # parameters directly derived from the above local scope.
-    func_wrapper_code_params = ''.join(
+    # parameters directly derived from the local scope established by the above
+    # calls to the _code_check_params() and _code_check_return() functions.
+    code_signature_params = ''.join(
         # For the name of each such parameter...
         (
             f'{CODE_INDENT_1}'
@@ -182,50 +203,44 @@ def generate_code(data: BeartypeData) -> str:
     )
 
     # Python code snippet declaring the signature of this wrapper.
-    code_sig = CODE_SIGNATURE.format(
+    code_signature = CODE_SIGNATURE.format(
+        func_wrapper_prefix=data.func_wrapper_code_signature_prefix,
         func_wrapper_name=data.func_wrapper_name,
-        func_wrapper_params=f'\n{func_wrapper_code_params}',
+        func_wrapper_params=code_signature_params,
     )
 
-    # Python code snippet declaring the signature of this wrapper followed by
-    # preliminary statements (e.g., assignment initializations) if desired
-    # *AFTER* generating snippets type-checking parameters and return values,
-    # both of which modify instance variables of the dataclass tested below.
-    code_init = (
+    # Python code snippet of preliminary statements (e.g., local variable
+    # assignments) if any *AFTER* generating snippets type-checking parameters
+    # and return values, both of which modify instance variables of the
+    # dataclass tested below.
+    code_body_init = (
         # If the body of this wrapper requires a pseudo-random integer, append
         # code generating and localizing such an integer to this signature.
-        f'{code_sig}{CODE_INIT_RANDOM_INT}'
+        CODE_INIT_RANDOM_INT
         if ARG_NAME_GETRANDBITS in data.func_wrapper_locals else
         # Else, this body requires *NO* such integer. In this case, preserve
         # this signature as is.
-        code_sig
+        ''
     )
 
-    # Python code defining the wrapper type-checking this callable.
-    #
+    # Return Python code defining the wrapper type-checking this callable.
     # While there exist numerous alternatives to string formatting (e.g.,
     # appending to a list or bytearray before joining the items of that
     # iterable into a string), these alternatives are either:
-    #
     # * Slower, as in the case of a list (e.g., due to the high up-front cost
     #   of list construction).
     # * Cumbersome, as in the case of a bytearray.
     #
     # Since string concatenation is heavily optimized by the official CPython
-    # interpreter, the simplest approach is the most ideal.
-    func_wrapper_code = f'{code_init}{code_params}{code_return}'
-
-    # Return either...
+    # interpreter, the simplest approach is the most ideal. KISS, bro.
     return (
-        # If this callable requires *NO* type-checking, the empty string
-        # instructing the parent @beartype decorator to reduce to a noop.
-        ''
-        if func_wrapper_code == f'{code_sig}{CODE_RETURN_UNCHECKED}' else
-        # Else, this code and local scope.
-        func_wrapper_code
+        f'{code_signature}'
+        f'{code_body_init}'
+        f'{code_check_params}'
+        f'{code_check_return}'
     )
 
-# ....................{ CODERS ~ private                  }....................
+# ....................{ PRIVATE ~ params                  }....................
 def _code_check_params(data: BeartypeData) -> str:
     '''
     Generate a Python code snippet type-checking all annotated parameters of
@@ -247,7 +262,7 @@ def _code_check_params(data: BeartypeData) -> str:
     BeartypeDecorParamNameException
         If the name of any parameter declared on this callable is prefixed by
         the reserved substring ``__bear``.
-    BeartypeDecorHintNonPepException
+    BeartypeDecorHintNonpepException
         If any type hint annotating any parameter of this callable is neither:
 
         * A PEP-noncompliant type hint.
@@ -259,6 +274,13 @@ def _code_check_params(data: BeartypeData) -> str:
     # Decorated callable.
     func = data.func
 
+    #FIXME: Optimize everything below away for argless callables: e.g.,
+    #    func_params = data.func_sig.parameters
+    #    if not func_params:
+    #        return ''
+    #Obviously, we'll want to ensure that we're testing decoration of argless
+    #callables. Are we? Let's hope so, as we're tired!
+
     # Python code snippet to be returned.
     func_wrapper_code = ''
 
@@ -276,7 +298,7 @@ def _code_check_params(data: BeartypeData) -> str:
 
     # ..................{ LOCALS ~ other                    }..................
     # Human-readable label describing the current parameter.
-    pith_label = None
+    exception_prefix = None
 
     # Type hint annotating this parameter if any *OR* "_PARAM_HINT_EMPTY"
     # otherwise (i.e., if this parameter is unannotated).
@@ -301,13 +323,13 @@ def _code_check_params(data: BeartypeData) -> str:
 
         # Human-readable labels describing the current parameter and type
         # hint annotating this parameter.
-        pith_label = label_callable_decorated_param(func, param_name)
+        exception_prefix = prefix_callable_decorated_param(func, param_name)
 
         # If this parameter's name is reserved for use by the @beartype
         # decorator, raise an exception.
         if param_name.startswith('__bear'):
             raise BeartypeDecorParamNameException(
-                f'{pith_label} reserved by @beartype.')
+                f'{exception_prefix}reserved by @beartype.')
         # If either the type of this parameter is silently ignorable, continue
         # to the next parameter.
         elif param_kind in _PARAM_KINDS_IGNORABLE:
@@ -321,11 +343,11 @@ def _code_check_params(data: BeartypeData) -> str:
         # supported PEP-compliant hint).
         #
         # Do this first *BEFORE* passing this hint to any further callables.
-        hint = coerce_hint_pep(
+        hint = sanify_hint_root(
+            hint=hint,
             func=func,
             pith_name=param_name,
-            hint=hint,
-            hint_label=f'{pith_label} type hint',
+            exception_prefix=f'{exception_prefix}type hint ',
         )
 
         # If this hint is ignorable, continue to the next parameter.
@@ -358,17 +380,17 @@ def _code_check_params(data: BeartypeData) -> str:
         # Append code type-checking this parameter against this hint.
         func_wrapper_code += func_wrapper_code_param
 
-    # If this callable accepts one or more positional parameters, prefix this
-    # code by a snippet localizing the number of these parameters.
+    # If this callable accepts one or more positional type-checked parameters,
+    # prefix this code by a snippet localizing the number of these parameters.
     if is_params_positional:
         func_wrapper_code = f'{CODE_INIT_ARGS_LEN}{func_wrapper_code}'
-    # Else, this callable accepts *NO* positional parameters. In this
-    # case, preserve this code as is.
+    # Else, this callable accepts *NO* positional type-checked parameters. In
+    # this case, preserve this code as is.
 
     # Return this code.
     return func_wrapper_code
 
-# ....................{ CODERS                            }....................
+# ....................{ PRIVATE ~ return                  }....................
 def _code_check_return(data: BeartypeData) -> str:
     '''
     Generate a Python code snippet type-checking the annotated return declared
@@ -387,7 +409,14 @@ def _code_check_return(data: BeartypeData) -> str:
 
     Raises
     ----------
-    BeartypeDecorHintNonPepException
+    :exc:`BeartypeDecorHintPep484585Exception`
+        If this callable is either:
+
+        * A coroutine *not* annotated by a :attr:`typing.Coroutine` type hint.
+        * A generator *not* annotated by a :attr:`typing.Generator` type hint.
+        * An asynchronous generator *not* annotated by a
+          :attr:`typing.AsyncGenerator` type hint.
+    :exc:`BeartypeDecorHintNonpepException`
         If the type hint annotating this return (if any) of this callable is
         neither:
 
@@ -401,24 +430,37 @@ def _code_check_return(data: BeartypeData) -> str:
     # Decorated callable.
     func = data.func
 
-    # Python code snippet to be returned.
-    func_wrapper_code = None
-
     # Type hint annotating this callable's return if any *OR*
     # "_RETURN_HINT_EMPTY" otherwise (i.e., if this return is unannotated).
     hint = data.func_sig.return_annotation
 
-    # If this return is unannotated, generate code calling this callable
-    # unchecked and returning this value from this wrapper.
+    # If this return is unannotated, silently reduce to a noop.
     if hint is _RETURN_HINT_EMPTY:
-        func_wrapper_code = CODE_RETURN_UNCHECKED
+        return ''
     # Else, this return is annotated.
+
+    # This hint reduced to a simpler hint if this hint is either PEP 484- *OR*
+    # 585-compliant *AND* requires reduction (e.g., from "Coroutine[None, None,
+    # str]" to just "str"), raising an exception if this hint is contextually
+    # invalid for this callable (e.g., generator whose return is *NOT*
+    # annotated as "Generator[...]").
     #
+    # Perform this reduction *BEFORE* performing subsequent tests (e.g., to
+    # accept "Coroutine[None, None, typing.NoReturn]" as expected).
+    hint = reduce_hint_pep484585_func_return(func)
+
+    # Python code snippet to be returned, defaulting to the empty string
+    # implying this callable's return to either be unannotated *OR* annotated
+    # by a safely ignorable type hint.
+    func_wrapper_code = ''
+
     # If this is the PEP 484-compliant "typing.NoReturn" type hint permitted
-    # *ONLY* as a return annotation, default this snippet to a pre-generated
-    # snippet validating this callable to *NEVER* successfully return. Yup!
-    elif hint is NoReturn:
-        func_wrapper_code = PEP484_CODE_CHECK_NORETURN
+    # *ONLY* as a return annotation...
+    if hint is NoReturn:
+        # Default this snippet to a pre-generated snippet validating this
+        # callable to *NEVER* successfully return. Yup!
+        func_wrapper_code = PEP484_CODE_CHECK_NORETURN.format(
+            func_call_prefix=data.func_wrapper_code_call_prefix)
     # Else, this is *NOT* "typing.NoReturn". In this case...
     else:
         # PEP-compliant type hint converted from this PEP-noncompliant type
@@ -426,22 +468,20 @@ def _code_check_return(data: BeartypeData) -> str:
         # is both PEP-compliant and supported, *OR* raise an exception
         # otherwise (i.e., if this hint is neither PEP-noncompliant nor a
         # supported PEP-compliant hint).
-        hint = coerce_hint_pep(
+        hint = sanify_hint_root(
+            hint=hint,
             func=func,
             pith_name='return',
-            hint=hint,
-            hint_label=f'{label_callable_decorated_return(func)} type hint',
+            exception_prefix=(
+                f'{prefix_callable_decorated_return(func)}type hint '),
         )
 
-        # If this PEP-compliant hint is ignorable, generate code calling this
-        # callable unchecked and returning that return from this wrapper.
-        if is_hint_ignorable(hint):
-            # print(f'Ignoring {data.func_name} return hint {repr(hint)}...')
-            func_wrapper_code = CODE_RETURN_UNCHECKED
-        # Else, this hint is unignorable. In this case...
-        else:
-            # Python code snippet type-checking this return against this hint.
+        # If this PEP-compliant hint is unignorable, generate and return a
+        # snippet type-checking this return against this hint.
+        if not is_hint_ignorable(hint):
             func_wrapper_code = pep_code_check_return(data=data, hint=hint)
+        # Else, this PEP-compliant hint is ignorable.
+        # if not func_wrapper_code: print(f'Ignoring {data.func_name} return hint {repr(hint)}...')
 
     # Return this code.
     return func_wrapper_code
