@@ -21,7 +21,7 @@ dramatically simplify code generation for these hints. Ergo, so we do.
 
 # ....................{ IMPORTS                           }....................
 from beartype_test.util.mod.pytmodtest import (
-    is_package_numpy_typing_ndarray_supported)
+    is_package_numpy_typing_ndarray_deep)
 
 # ....................{ ADDERS                            }....................
 def add_data(data_module: 'ModuleType') -> None:
@@ -35,12 +35,13 @@ def add_data(data_module: 'ModuleType') -> None:
         Module to be added to.
     '''
 
-    # If @beartype does *NOT* support the "numpy.typing.NDArray" type hint
-    # under the active Python, reduce to a noop.
-    if not is_package_numpy_typing_ndarray_supported():
+    # ..................{ UNSUPPORTED                       }..................
+    # If beartype does *NOT* deeply support "numpy.typing.NDArray" type hints
+    # under the active Python interpreter, silently reduce to a noop.
+    if not is_package_numpy_typing_ndarray_deep():
         return
-    # If @beartype supports the "numpy.typing.NDArray" type hint under the
-    # active Python.
+    # Else, beartype deeply supports "numpy.typing.NDArray" type hints under
+    # the active Python interpreter.
 
     # ..................{ IMPORTS                           }..................
     # Defer attribute-dependent imports.
@@ -53,10 +54,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HINT_ATTR_TUPLE,
     )
     from beartype._util.mod.utilmodimport import import_module_typing_any_attr
-    from beartype._util.py.utilpyversion import (
-        IS_PYTHON_AT_LEAST_3_8,
-        IS_PYTHON_AT_LEAST_3_9,
-    )
+    from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_9
     from beartype_test.a00_unit.data.hint.util.data_hintmetacls import (
         HintPepMetadata,
         HintPithSatisfiedMetadata,
@@ -64,20 +62,20 @@ def add_data(data_module: 'ModuleType') -> None:
     )
 
     # Defer NumPy-specific imports.
-    from numpy import asarray, dtype, float64
+    from numpy import asarray, dtype, float32, float64, floating
     from numpy.typing import NDArray
 
     # ..................{ TUPLES                            }..................
     # Add NumPy-specific test type hints to this tuple global.
     data_module.HINTS_PEP_META.extend((
-        # ................{ NUMPY ~ array                     }................
+        # ................{ NUMPY ~ array : dtype : equals    }................
         # NumPy array subscripted by a true data type.
         HintPepMetadata(
             hint=NDArray[dtype(float64)],
             pep_sign=HintSignNumpyArray,
             # "NDArray" is implemented as:
             # * Under Python >= 3.9, a PEP 585-compliant generic.
-            # * Under Python < 3.9, a pure-Python generic backport.
+            # * Under Python >= 3.8, a pure-Python generic backport.
             is_pep585_builtin=IS_PYTHON_AT_LEAST_3_9,
             is_type_typing=False,
             is_typing=False,
@@ -97,7 +95,7 @@ def add_data(data_module: 'ModuleType') -> None:
                 ),
                 # NumPy array containing only 64-bit integers.
                 HintPithUnsatisfiedMetadata(
-                    pith=((4, 36, 624, 3744, 5108, 10200, 54912, 123552,)),
+                    pith=asarray((4, 36, 624, 3744, 5108, 10200, 54912,)),
                     # Match that the exception message raised for this object
                     # embeds the representation of the expected data type.
                     exception_str_match_regexes=(r'\bfloat64\b',),
@@ -115,9 +113,8 @@ def add_data(data_module: 'ModuleType') -> None:
             is_typing=False,
             piths_satisfied_meta=(
                 # NumPy array containing only 64-bit floats.
-                HintPithSatisfiedMetadata(
-                    asarray((2.0, 2.5, 2.6, 2.7083, 2.716, 2.71805,)),
-                ),
+                HintPithSatisfiedMetadata(asarray(
+                    (2.0, 2.5, 2.6, 2.7083, 2.716, 2.71805,))),
             ),
             piths_unsatisfied_meta=(
                 # String constant.
@@ -129,22 +126,43 @@ def add_data(data_module: 'ModuleType') -> None:
                 ),
                 # NumPy array containing only 64-bit integers.
                 HintPithUnsatisfiedMetadata(
-                    pith=((1, 1, 1, 1, 2, 3, 6, 11, 23, 47, 106, 235, 551,)),
+                    pith=asarray((1, 1, 1, 1, 2, 3, 6, 11, 23, 47, 106, 235,)),
                     # Match that the exception message raised for this object
                     # embeds the representation of the expected data type.
                     exception_str_match_regexes=(r'\bfloat64\b',),
                 ),
             ),
         ),
-    ))
 
-    # ..................{ VALIDATORS                        }..................
-    # If the active Python interpreter does *NOT* support Python >= 3.8 and
-    # thus the __class_getitem__() dunder method required for beartype
-    # validators, immediately return.
-    if not IS_PYTHON_AT_LEAST_3_8:
-        return
-    # Else, this interpreter supports beartype validators.
+        # ................{ NUMPY ~ array : dtype : subclass  }................
+        # NumPy array subscripted by a data type superclass.
+        HintPepMetadata(
+            hint=NDArray[floating],
+            pep_sign=HintSignNumpyArray,
+            is_pep585_builtin=IS_PYTHON_AT_LEAST_3_9,
+            is_type_typing=False,
+            is_typing=False,
+            piths_satisfied_meta=(
+                # NumPy array containing only 32-bit floats.
+                HintPithSatisfiedMetadata(asarray(
+                    (1.2, 2.4, 3.0, 3.6, 4.0, 4.5, 4.8, 5.6, 6.0, 6.3, 7.0,),
+                    dtype=float32,
+                )),
+                # NumPy array containing only 64-bit floats.
+                HintPithSatisfiedMetadata(asarray(
+                    (3.2, 5, 1, 2, 1, 8, 2, 5, 1, 3, 1, 2.8, 1, 1.5, 1, 1, 4,),
+                    dtype=float64,
+                )),
+            ),
+            piths_unsatisfied_meta=(
+                # String constant.
+                HintPithUnsatisfiedMetadata('Then, and'),
+                # NumPy array containing only 64-bit integers.
+                HintPithUnsatisfiedMetadata(asarray(
+                    (3, 6, 5, 12, 7, 18, 9, 12, 11, 30, 13, 16, 15, 18, 17,))),
+            ),
+        ),
+    ))
 
     # ..................{ VALIDATORS ~ hints                }..................
     # "typing.Annotated" type hint factory imported from either the "typing" or
@@ -167,7 +185,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=HINT_ATTR_TUPLE[Numpy1DFloat64Array, Numpy1DFloat64Array],
             pep_sign=HintSignTuple,
-            stdlib_type=tuple,
+            isinstanceable_type=tuple,
             is_pep585_builtin=HINT_ATTR_TUPLE is tuple,
             piths_satisfied_meta=(
                 # 2-tuple of NumPy arrays containing only 64-bit floats.
