@@ -23,7 +23,7 @@ def add_data(data_module: 'ModuleType') -> None:
         Module to be added to.
     '''
 
-    # "typing.Annotated" type hint factory imported from either the "typing" or
+    # "Annotated" type hint factory imported from either the "typing" or
     # "typing_extensions" modules if importable *OR* "None" otherwise.
     Annotated = import_module_typing_any_attr_or_none_safe('Annotated')
 
@@ -35,7 +35,12 @@ def add_data(data_module: 'ModuleType') -> None:
 
     # ..................{ IMPORTS                           }..................
     # Defer attribute-dependent imports.
-    from beartype.vale import Is, IsAttr, IsEqual
+    from beartype.vale import (
+        Is,
+        IsAttr,
+        IsEqual,
+        IsSubclass,
+    )
     from beartype._data.hint.pep.sign.datapepsigns import (
         HintSignAnnotated,
         HintSignList,
@@ -43,7 +48,8 @@ def add_data(data_module: 'ModuleType') -> None:
     from beartype._util.hint.pep.utilpepattr import (
         HINT_ATTR_LIST,
     )
-    from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_8
+    from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_7
+    from beartype_test.a00_unit.data.data_type import Class, Subclass
     from beartype_test.a00_unit.data.hint.util.data_hintmetacls import (
         HintPepMetadata,
         HintPithSatisfiedMetadata,
@@ -73,16 +79,15 @@ def add_data(data_module: 'ModuleType') -> None:
 
         # Deeply ignorable PEP 484-, 585-, and 593-compliant type hint
         # exercising numerous edge cases broken under prior releases.
-        Union[
-            str, HINT_ATTR_LIST[int], NewType(
-                'MetaType', Annotated[object, 53])],
+        Union[str, HINT_ATTR_LIST[int], NewType(
+            'MetaType', Annotated[object, 53])],
     ))
 
     # ..................{ TUPLES                            }..................
     # Add PEP 593-specific test type hints to this tuple global.
     data_module.HINTS_PEP_META.extend((
         # ................{ ANNOTATED                         }................
-        # Hashable annotated of a isinstanceable type annotated by an arbitrary
+        # Hashable annotated of an isinstanceable type annotated by an arbitrary
         # hashable object.
         HintPepMetadata(
             hint=Annotated[str, int],
@@ -99,23 +104,6 @@ def add_data(data_module: 'ModuleType') -> None:
             ),
         ),
 
-        # Unhashable annotated of a isinstanceable type annotated by an
-        # unhashable mutable container.
-        HintPepMetadata(
-            hint=Annotated[str, []],
-            pep_sign=HintSignAnnotated,
-            piths_satisfied_meta=(
-                # String constant.
-                HintPithSatisfiedMetadata(
-                    'Papally Ľust‐besmirched Merchet laws'),
-            ),
-            piths_unsatisfied_meta=(
-                # List of string constants.
-                HintPithUnsatisfiedMetadata([
-                    "Of our ôver‐crowdedly cowed crowd's opinion‐",]),
-            ),
-        ),
-
         # Annotated of a "typing" type.
         HintPepMetadata(
             hint=Annotated[HINT_ATTR_LIST[str], int],
@@ -135,14 +123,6 @@ def add_data(data_module: 'ModuleType') -> None:
 
     ))
 
-    # ..................{ VALIDATORS                        }..................
-    # If the active Python interpreter does *NOT* support Python >= 3.8 and
-    # thus the __class_getitem__() dunder method required for beartype
-    # validators, immediately return.
-    if not IS_PYTHON_AT_LEAST_3_8:
-        return
-    # Else, this interpreter supports beartype validators.
-
     # ..................{ VALIDATORS ~ is                   }..................
     # Beartype-specific validators defined as lambda functions.
     IsLengthy = Is[lambda text: len(text) > 30]
@@ -156,19 +136,14 @@ def add_data(data_module: 'ModuleType') -> None:
     # via the domain-specific language (DSL) implemented by those validators.
     IsLengthyOrUnquotedSentence = IsLengthy | (IsSentence & ~IsQuoted)
 
-    # ..................{ VALIDATORS ~ isequal              }..................
-    # Arbitrary list to validate equality against.
-    AMPLY_IMPISH = ['Amply imp‐ish', 'blandishments to']
-
-    # Beartype-specific validator validating equality against that list.
-    IsEqualAmplyImpish = IsEqual[AMPLY_IMPISH]
-
-    # ..................{ VALIDATORS ~ hints                }..................
-    # Annotated of a isinstanceable type annotated by one beartype-specific
+    # Annotated of an isinstanceable type annotated by one beartype-specific
     # validator defined as a lambda function.
     AnnotatedStrIsLength = Annotated[str, IsLengthy]
 
     # ..................{ VALIDATORS ~ isattr               }..................
+    # Arbitrary list to validate equality against below.
+    AMPLY_IMPISH = ['Amply imp-ish', 'blandishments to']
+
     class CathecticallyEnsconceYouIn(object):
         '''
         Arbitrary class defining an arbitrary attribute whose value has *no*
@@ -200,7 +175,7 @@ def add_data(data_module: 'ModuleType') -> None:
     # Add PEP 593-specific test type hints to this tuple global.
     data_module.HINTS_PEP_META.extend((
         # ................{ ANNOTATED ~ beartype : is         }................
-        # Annotated of a isinstanceable type annotated by one beartype-specific
+        # Annotated of an isinstanceable type annotated by one beartype-specific
         # validator defined as a lambda function.
         HintPepMetadata(
             hint=AnnotatedStrIsLength,
@@ -224,7 +199,7 @@ def add_data(data_module: 'ModuleType') -> None:
             ),
         ),
 
-        # Annotated of a isinstanceable type annotated by two or more
+        # Annotated of an isinstanceable type annotated by two or more
         # beartype-specific validators all defined as functions, specified
         # with comma-delimited list syntax.
         HintPepMetadata(
@@ -259,7 +234,7 @@ def add_data(data_module: 'ModuleType') -> None:
             ),
         ),
 
-        # Annotated of a isinstanceable type annotated by two or more
+        # Annotated of an isinstanceable type annotated by two or more
         # beartype-specific validators all defined as functions, specified
         # with "&"-delimited operator syntax.
         HintPepMetadata(
@@ -294,7 +269,7 @@ def add_data(data_module: 'ModuleType') -> None:
             ),
         ),
 
-        # Annotated of a isinstanceable type annotated by one beartype-specific
+        # Annotated of an isinstanceable type annotated by one beartype-specific
         # validator synthesized from all possible operators.
         HintPepMetadata(
             hint=Annotated[str, IsLengthyOrUnquotedSentence],
@@ -354,7 +329,7 @@ def add_data(data_module: 'ModuleType') -> None:
         HintPepMetadata(
             hint=HINT_ATTR_LIST[AnnotatedStrIsLength],
             pep_sign=HintSignList,
-            stdlib_type=list,
+            isinstanceable_type=list,
             is_pep585_builtin=HINT_ATTR_LIST is list,
             piths_satisfied_meta=(
                 # List of string constants satisfying this validator.
@@ -381,40 +356,9 @@ def add_data(data_module: 'ModuleType') -> None:
             ),
         ),
 
-        # ................{ ANNOTATED ~ beartype : isequal    }................
-        # Annotated of a isinstanceable type annotated by one beartype-specific
-        # equality validator.
-        HintPepMetadata(
-            hint=Annotated[HINT_ATTR_LIST[str], IsEqualAmplyImpish],
-            pep_sign=HintSignAnnotated,
-            piths_satisfied_meta=(
-                # Exact object subscripting this validator.
-                HintPithSatisfiedMetadata(AMPLY_IMPISH),
-                # Object *NOT* subscripting this validator but equal to this
-                # object.
-                HintPithSatisfiedMetadata(AMPLY_IMPISH[:]),
-            ),
-            piths_unsatisfied_meta=(
-                # String constant *NOT* an instance of the expected type.
-                HintPithUnsatisfiedMetadata(
-                    pith='May Your coarsest, Incessantly cast‐off jobs of a',
-                    # Match that the exception message raised for this object
-                    # embeds a string in the expected list.
-                    exception_str_match_regexes=(
-                        r"IsEqual\[.*'Amply imp‐ish',.*\]",),
-                ),
-                # List of integer constants *NOT* instances of the expected
-                # subtype.
-                HintPithUnsatisfiedMetadata([1, 2, 3, 6, 7, 14, 21, 42,]),
-                # List of string constants violating this validator.
-                HintPithUnsatisfiedMetadata(
-                    ['Hectic,', 'receptacle‐hybernacling caste so',]),
-            ),
-        ),
-
         # ................{ ANNOTATED ~ beartype : isattr     }................
-        # Annotated of a isinstanceable type annotated by one beartype-specific
-        # attribute validator.
+        # Annotated of an isinstanceable type annotated by one
+        # beartype-specific attribute validator.
         HintPepMetadata(
             hint=Annotated[
                 CathecticallyEnsconceYouIn, IsAttrThisMobbedTristeOf],
@@ -436,4 +380,86 @@ def add_data(data_module: 'ModuleType') -> None:
                 HintPithUnsatisfiedMetadata(SORDIDLY_FLABBY_WRMCASTINGS),
             ),
         ),
+
+        # ................{ ANNOTATED ~ beartype : isequal    }................
+        # Annotated of an isinstanceable type annotated by one
+        # beartype-specific equality validator.
+        HintPepMetadata(
+            hint=Annotated[HINT_ATTR_LIST[str], IsEqual[AMPLY_IMPISH]],
+            pep_sign=HintSignAnnotated,
+            piths_satisfied_meta=(
+                # Exact object subscripting this validator.
+                HintPithSatisfiedMetadata(AMPLY_IMPISH),
+                # Object *NOT* subscripting this validator but equal to this
+                # object.
+                HintPithSatisfiedMetadata(AMPLY_IMPISH[:]),
+            ),
+            piths_unsatisfied_meta=(
+                # String constant *NOT* an instance of the expected type.
+                HintPithUnsatisfiedMetadata(
+                    pith='May Your coarsest, Incessantly cast‐off jobs of a',
+                    # Match that the exception message raised for this object
+                    # embeds a string in the expected list.
+                    exception_str_match_regexes=(r"'Amply imp-ish'",),
+                ),
+                # List of integer constants *NOT* instances of the expected
+                # subtype.
+                HintPithUnsatisfiedMetadata([1, 2, 3, 6, 7, 14, 21, 42,]),
+                # List of string constants violating this validator.
+                HintPithUnsatisfiedMetadata(
+                    ['Hectic,', 'receptacle‐hybernacling caste so',]),
+            ),
+        ),
+
+        # ................{ ANNOTATED ~ beartype : issubclass }................
+        # Annotated of an isinstanceable type annotated by one
+        # beartype-specific equality validator.
+        HintPepMetadata(
+            hint=Annotated[type, IsSubclass[Class]],
+            pep_sign=HintSignAnnotated,
+            piths_satisfied_meta=(
+                # Class subscripting this validator.
+                HintPithSatisfiedMetadata(Class),
+                # Class subclassing the class subscripting this validator.
+                HintPithSatisfiedMetadata(Subclass),
+            ),
+            piths_unsatisfied_meta=(
+                # String constant *NOT* an instance of the expected type.
+                HintPithUnsatisfiedMetadata(
+                    pith='May Your coarsest, Incessantly cast‐off jobs of a',
+                    # Match that the exception message raised for this object
+                    # embeds a classname in the expected list.
+                    exception_str_match_regexes=(r'\bClass\b',),
+                ),
+                # Class *NOT* subclassing the class subscripting this
+                # validator.
+                HintPithUnsatisfiedMetadata(str),
+            ),
+        ),
     ))
+
+    # If the active Python interpreter targets Python >= 3.7, the "typing"
+    # module is sufficiently sane to support subscripting the third-party
+    # "typing_extensions.Literal" factory by unhashable objects. Under Python
+    # 3.6, these type hints fail at subscription time with non-human-readable
+    # exceptions resembling:
+    #     TypeError: unhashable type: 'list'
+    if IS_PYTHON_AT_LEAST_3_7:
+        data_module.HINTS_PEP_META.extend((
+            # Unhashable annotated of an isinstanceable type annotated by an
+            # unhashable mutable container.
+            HintPepMetadata(
+                hint=Annotated[str, []],
+                pep_sign=HintSignAnnotated,
+                piths_satisfied_meta=(
+                    # String constant.
+                    HintPithSatisfiedMetadata(
+                        'Papally Ľust‐besmirched Merchet laws'),
+                ),
+                piths_unsatisfied_meta=(
+                    # List of string constants.
+                    HintPithUnsatisfiedMetadata([
+                        "Of our ôver‐crowdedly cowed crowd's opinion‐",]),
+                ),
+            ),
+        ))
